Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FromBcrypt ¶
func FromCasbin ¶
func IsQueryCancelled ¶
IsQueryCancelled returns true if an error is a query cancellation.
func IsUniqueViolation ¶
IsUniqueViolation returns true if an error is a unique violation.
Types ¶
type Code ¶
type Code int
const ( Canceled Code = 1 Unknown Code = 2 InvalidArgument Code = 3 DeadlineExceeded Code = 4 NotFound Code = 5 AlreadyExists Code = 6 PermissionDenied Code = 7 ResourceExhausted Code = 8 FailedPrecondition Code = 9 Aborted Code = 10 OutOfRange Code = 11 Unimplemented Code = 12 Internal Code = 13 DataLoss Code = 15 Unauthenticated Code = 16 )
Click to show internal directories.
Click to hide internal directories.